diff --git a/web/pgadmin/__init__.py b/web/pgadmin/__init__.py
index 9cb55cfc..baf0ca30 100644
--- a/web/pgadmin/__init__.py
+++ b/web/pgadmin/__init__.py
@@ -646,8 +646,11 @@ def create_app(app_name=None):
         # if the server is restarted the in memory key will be lost
         # but the user session may still be active. Logout the user
         # to get the key again when login
-        if config.SERVER_MODE and current_app.keyManager.get() is None:
-            logout_user()
+        if config.SERVER_MODE and current_user.is_authenticated:
+            if current_app.keyManager.get() is None and \
+                    request.endpoint not in ('security.login',
+                                             'security.logout'):
+                logout_user()
 
     @app.after_request
     def after_request(response):
diff --git a/web/pgadmin/browser/templates/browser/index.html b/web/pgadmin/browser/templates/browser/index.html
index 0a785d6b..8b3866c2 100644
--- a/web/pgadmin/browser/templates/browser/index.html
+++ b/web/pgadmin/browser/templates/browser/index.html
@@ -78,7 +78,6 @@ require.onResourceLoad = function (context, map, depMaps) {
 window.onload = function(e){
  setTimeout(function() {
    var gravatarImg = {{ IMG.PREPARE_HTML()|safe }}
-   //$('#navbar-menu .navbar-right > li > a').html(gravatarImg);
    var navbarUser = document.getElementById("navbar-user");
    if (navbarUser) {
      navbarUser.innerHTML = gravatarImg;
@@ -88,6 +87,10 @@ window.onload = function(e){
 {% endif %}
 {% endblock %}
 
+{% block css_link %}
+<link type="text/css" rel="stylesheet" href="{{ url_for('browser.browser_css')}}"/>
+{% endblock %}
+
 {% block body %}
 <div id="pg-spinner" class="pg-sp-container">
   <div class="pg-sp-content">
diff --git a/web/pgadmin/templates/base.html b/web/pgadmin/templates/base.html
index 7a53c311..8a7b255b 100644
--- a/web/pgadmin/templates/base.html
+++ b/web/pgadmin/templates/base.html
@@ -20,7 +20,6 @@
 
     <!-- Base template stylesheets -->
     <link type="text/css" rel="stylesheet" href="{{ url_for('static', filename='vendor/backgrid/backgrid.css')}}"/>
-    <link type="text/css" rel="stylesheet" href="{{ url_for('browser.browser_css')}}"/>
     <link type="text/css" rel="stylesheet" href="{{ url_for('static', filename='js/generated/style.css')}}"/>
     <link type="text/css" rel="stylesheet" href="{{ url_for('static', filename='js/generated/pgadmin.css')}}"/>
     <link type="text/css" rel="stylesheet" href="{{ url_for('static', filename='css/alertify.noanimation.css')}}" id="alertify-no-animation"/>
diff --git a/web/pgadmin/utils/session.py b/web/pgadmin/utils/session.py
index 7c0b6af2..18d16121 100644
--- a/web/pgadmin/utils/session.py
+++ b/web/pgadmin/utils/session.py
@@ -364,7 +364,10 @@ def pga_unauthorised():
             info='PGADMIN_LOGIN_REQUIRED'
         )
 
-    if login_message:
+    # flash messages are only required if the request was from a
+    # security page, otherwise it will be redirected to login page
+    # anyway
+    if login_message and 'security' in request.endpoint:
         flash(login_message, category=lm.login_message_category)
 
     return redirect(login_url(lm.login_view, request.url))
